@@ -10,6 +10,7 @@ import astropy.units as u
 from astropy import time
 from astropy import coordinates as coord
 from astropy.wcs.wcsapi import HighLevelWCSWrapper
+import gwcs.coordinate_frames as cf
 
 
 # Shorthand the name of the 2d gwcs fixture
@@ -166,6 +167,12 @@ def test_world_axis_object_components_2d(gwcs_2d_spatial_shift):
                     ('celestial', 1, 'spherical.lat')]
 
 
+def test_world_axis_object_components_2d_generic(gwcs_2d_quantity_shift):
+    waoc = gwcs_2d_quantity_shift.world_axis_object_components
+    assert waoc == [('SPATIAL', 0, 'value'),
+                    ('SPATIAL1', 0, 'value')]
+
+
 def test_world_axis_object_components_1d(gwcs_1d_freq):
     waoc = gwcs_1d_freq.world_axis_object_components
     assert waoc == [('spectral', 0, 'value')]
@@ -189,6 +196,18 @@ def test_world_axis_object_classes_2d(gwcs_2d_spatial_shift):
     assert waoc['celestial'][2]['unit'] == (u.deg, u.deg)
 
 
+def test_world_axis_object_classes_2d_generic(gwcs_2d_quantity_shift):
+    waoc = gwcs_2d_quantity_shift.world_axis_object_classes
+    assert waoc['SPATIAL'][0] is u.Quantity
+    assert waoc['SPATIAL1'][0] is u.Quantity
+    assert waoc['SPATIAL'][1] == tuple()
+    assert waoc['SPATIAL1'][1] == tuple()
+    assert 'unit' in waoc['SPATIAL'][2]
+    assert 'unit' in waoc['SPATIAL1'][2]
+    assert waoc['SPATIAL'][2]['unit'] == u.km
+    assert waoc['SPATIAL1'][2]['unit'] == u.km
+
+
 def test_world_axis_object_classes_4d(gwcs_4d_identity_units):
     waoc = gwcs_4d_identity_units.world_axis_object_classes
     assert waoc['celestial'][0] is coord.SkyCoord
@@ -458,3 +477,18 @@ def test_ndim_str_frames(gwcs_with_frames_strings):
     wcsobj = gwcs_with_frames_strings
     assert wcsobj.pixel_n_dim == 4
     assert wcsobj.world_n_dim == 3
+
+def test_composite_many_base_frame():
+    q_frame_1 = cf.CoordinateFrame(name='distance', axes_order=(0,), naxes=1, axes_type="SPATIAL", unit=(u.m,))
+    q_frame_2 = cf.CoordinateFrame(name='distance', axes_order=(1,), naxes=1, axes_type="SPATIAL", unit=(u.m,))
+    frame = cf.CompositeFrame([q_frame_1, q_frame_2])
+
+    wao_classes = frame._world_axis_object_classes
+
+    assert len(wao_classes) == 2
+    assert not set(wao_classes.keys()).difference({"SPATIAL", "SPATIAL1"})
+
+    wao_components = frame._world_axis_object_components
+
+    assert len(wao_components) == 2
+    assert not {c[0] for c in wao_components}.difference({"SPATIAL", "SPATIAL1"})
